@@ -157,6 +157,16 @@ logging.LogRecord.getMessage = LogRecord_getMessage_i18n
 #------------------------------------------------------------------------------
 def main(args=None):
 
+  print('''\
+
+*******************************************************************************
+***       DEPRECATION WARNING: The "pdns" project has been deprecated       ***
+***   and replaced by the "dnssync" (https://pypi.python.org/pypi/dnssync)  ***
+***                    project. Please use that instead.                    ***
+*******************************************************************************
+
+''', file=sys.stderr)
+
   common = argparse.ArgumentParser(add_help=False)
 
   common.add_argument(
