@@ -22,6 +22,7 @@
 import sys
 import six
 import dns.zone
+import dns.rdata
 import difflib
 import re
 import blessings
@@ -55,7 +56,8 @@ dnsname_re = re.compile(
   (?:
     (?![0-9]+\.)                # sld name components cannot be numbers-only
     (?!-)                       # name components cannot start with a dash
-    [a-zA-Z0-9-]{1,63}          # at most 63 alpha-numeric + dash characters
+    [a-zA-Z0-9_]                # first character alpha-numeric + underscore
+    [a-zA-Z0-9-]{0,62}          # at most 62 alpha-numeric + dash characters
     (?<!-)                      # name components cannot end with a dash
     \.
   )+
@@ -87,6 +89,15 @@ def reldom(domain):
     domain = domain[:-1]
   return domain
 
+#------------------------------------------------------------------------------
+def escapeContent(text):
+  if not text:
+    return text
+  # todo: `dns.rdata._escapify` should really be doing this detection for me...
+  if ';' not in text and ' ' not in text and '"' not in text:
+    return text
+  return '"' + dns.rdata._escapify(text) + '"'
+
 #------------------------------------------------------------------------------
 def downloadZone(ctxt):
   # TODO: i should really be building this from dns.zone.* calls...
@@ -96,6 +107,9 @@ def downloadZone(ctxt):
     fmt = RECORDFMTS.get(record.Type, RECORDFMTS.get('*'))
     record.Content = ' '.join([
       absdom(comp) for comp in record.Content.split()])
+    # todo: is TXT really the only record type?...
+    if record.Type == 'TXT':
+      record.Content = escapeContent(record.Content)
     lines.append(fmt.format(
       name     = absdom(record.Name),
       ttl      = record.TimeToLive,
@@ -193,6 +207,10 @@ def updateRecord(ctxt, records, record):
     update.Priority = record.rdata.preference
     update.Content  = record.rdata.exchange.to_text()
 
+  if update.Type == 'TXT':
+    # todo: is this how they should all be done?...
+    update.Content = ' '.join(record.rdata.strings)
+
   # PowerDNS does not seem to support absolute DNS names... ugh.
   update.Name    = reldom(update.Name)
   update.Content = ' '.join([reldom(comp) for comp in update.Content.split(' ')])
